.. include:: ../README.rst

Table of Contents
-----------------

.. toctree::
   :maxdepth: 1

   pages/getting_started
   pages/changelog
   pages/code_overview
   pages/contributor_guidelines


Other Relevant Pages
--------------------

* `PRAW's Source Code <https://github.com/praw-dev/praw>`_
* `reddit's Source Code <https://github.com/reddit/reddit>`_
* `reddit's API Wiki Page <https://github.com/reddit/reddit/wiki/API>`_
* `reddit's API Documentation <https://www.reddit.com/dev/api>`_

* `reddit Markdown Primer
  <https://www.reddit.com/r/reddit.com/comments/6ewgt/reddit_markdown_primer_or
  _how_do_you_do_all_that/c03nik6>`_
* `reddit.com's FAQ <https://www.reddit.com/wiki/faq>`_
* `reddit.com's Status Twitterbot <https://twitter.com/redditstatus/>`_.
  Tweets when reddit goes up or down
* `r/changelog <https://www.reddit.com/r/changelog/>`_. Significant changes to
  reddit's codebase will be announced here in non-developer speak
* `r/redditdev <https://www.reddit.com/r/redditdev>`_. Ask questions about
  reddit's codebase, PRAW and other API clients here
